import {
	Body,
	Controller,
	DefaultValuePipe,
	Delete,
	Get,
	HttpCode,
	HttpStatus,
	Param,
	ParseBoolPipe,
	ParseIntPipe,
	Post,
	Query,
	UseGuards,
} from "@nestjs/common";
import { AdminGuard } from "apps/backend/src/app/auth/auth.guard";
import { CreateMachineDto } from "apps/backend/src/app/machines/machines.dto";
import { MachinesService } from "apps/backend/src/app/machines/machines.service";

@Controller("machines")
export class MachinesController {
	constructor(private readonly machineService: MachinesService) {}

	@Get("find")
	async findMany(
		@Query("limit", new DefaultValuePipe(20), ParseIntPipe) limit: number,
		@Query("offset", new DefaultValuePipe(0), ParseIntPipe) offset: number,
		@Query("search", new DefaultValuePipe("")) search: string,
	) {
		return await this.machineService.findMany(limit, offset, search);
	}

	//TODO DTO
	@UseGuards(AdminGuard)
	@Post("new")
	async newMachine(@Body() body: CreateMachineDto) {
		return await this.machineService.create(body.machineName, body.machineType);
	}

	@UseGuards(AdminGuard)
	@Delete(":machineId")
	async deleteMachine(@Param("machineId") machineId: string) {}

	//TODO Patch

	//TODO CRUD fileType associated to machine

	@HttpCode(HttpStatus.OK)
	@Get("files/:machineId")
	async getFilesForMachine(
		@Query("limit", new DefaultValuePipe(20), ParseIntPipe) limit: number,
		@Query("offset", new DefaultValuePipe(0), ParseIntPipe) offset: number,
		@Query("search", new DefaultValuePipe("")) search: string,
		@Param("machineId") machineId: string,
	) {
		return this.machineService.findFilesForMachine(
			limit,
			offset,
			search,
			machineId,
		);
	}
}
